<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Anova_Elementor_Give_Donations extends Widget_Base {

	public function get_name() {
		return 'anova_elementor_give_donations';
	}

	public function get_title() {
		return esc_html__( 'Give Donations', 'anova' );
	}

	public function get_icon() {
		return 'eicon-price-table';
	}

	public function get_categories() {
		return [ 'anova' ];
	}

	public function get_script_depends() {
		return [ 'anova-elementor-give-donations' ];
	}

	protected function register_controls() {

		/***** Layout Section *****/
		$this->start_controls_section(
			'section_layout',
			[
				'label' => esc_html__( 'Layout', 'anova' ),
			]
		);

		$this->add_control(
			'type',
			[
				'label' => esc_html__( 'Type', 'anova' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'type1',
				'options' => [
					'type1' => esc_html__('Type 1', 'anova'),
					'type2' => esc_html__('Type 2', 'anova'),
					'type3' => esc_html__('Type 3', 'anova'),
					'type4' => esc_html__('Type 4', 'anova'),
				]
			]
		);

		$this->add_control(
			'layout_columns',
			[
				'label' => esc_html__( 'Columns', 'anova' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'two_column',
				'options' => [
					'one_column'  	=> esc_html__( '1 Columns', 'anova' ),
					'two_column'  	=> esc_html__( '2 Columns', 'anova' ),
					'three_column'  => esc_html__( '3 Columns', 'anova' ),
					'four_column'   => esc_html__( '4 Columns', 'anova' ),
				],
				'condition' => [
					'type!' => 'type4'
				]
			]
		);

		$this->add_control(
			'visibility',
			[
				'label' 	=> esc_html__( 'Visibility', 'anova' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'public',
				'options' 	=> [
					'public' 	=> esc_html__( 'Public', 'anova' ),
					'featured' => esc_html__( 'Featured Give Form', 'anova' ),
				],
			]
		);

		$args = array(
			'taxonomy' => 'give_forms_category',
		  	'orderby' 	=> 'name',
		  	'order' 	=> 'ASC'
		);

		$categories  	= get_categories($args);
		$cate_array 	= array();
		$arrayCateAll 	= array( 'all' => esc_html__( 'All categories', 'anova' ) );
		
		if ($categories) {
			foreach ( $categories as $cate ) {
				$cate_array[$cate->slug] = $cate->cat_name;
			}
		} else {
			$cate_array[ esc_html__( 'No content Category found', 'anova' ) ] = 0;
		}

		$this->add_control(
			'category',
			[
				'label' 	=> esc_html__( 'Category', 'anova' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'all',
				'options' 	=> array_merge($arrayCateAll,$cate_array),
			]
		);


		$this->add_control(
			'number_items',
			[
				'label' => esc_html__( 'Number Items', 'anova' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 3,
			]
		);

		$this->add_control(
			'order',
			[
				'label' => esc_html__('Order', 'anova'),
				'type' 	=> Controls_Manager::SELECT,
				'default' => 'desc',
				'options' => [
					'asc' 	=> esc_html__('Ascending', 'anova'),
					'desc' 	=> esc_html__('Descending', 'anova'),
				]
			]
		);

		$this->add_control(
			'orderby',
			[
				'label' 	=> esc_html__('Order By', 'anova'),
				'type' 		=> \Elementor\Controls_Manager::SELECT,
				'default' 	=> 'ID',
				'options' 	=> [
					'ID' 		=> esc_html__('ID', 'anova'),
					'title' 	=> esc_html__('Title', 'anova'),
					'date' 		=> esc_html__('Date', 'anova'),
					'modified' 	=> esc_html__('Modified', 'anova'),
					'rand' 		=> esc_html__('Rand', 'anova'),
				]
			]
		);

		$this->add_control(
			'limit_text',
			[
				'label' 	=> esc_html__( 'Description Words Limit', 'anova' ),
				'type' 		=> Controls_Manager::NUMBER,
				'default' 	=> 12,
			]
		);


		$this->end_controls_section();
		/***** End Layout Section *****/

		//SECTION TAB STYLE TITLE
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'anova' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_typography_title',
					'label' 	=> esc_html__( 'Typography', 'anova' ),
					'selector' 	=> '{{WRAPPER}} .ova_give_detail .detail_body .title',
				]
			);

			$this->add_control(
				'color_title',
				[
					'label' 	=> esc_html__( 'Color', 'anova' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova_give_detail .detail_body  .title' => 'color : {{VALUE}};',
						'{{WRAPPER}} .ova_give_detail .detail_body  .title a' => 'color : {{VALUE}};',	
					],
				]
			);

			$this->add_control(
				'color_title_hover',
				[
					'label' 	=> esc_html__( 'Color hover', 'anova' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova_give_detail .detail_body .title a:hover' => 'color : {{VALUE}};'
					],
					
				]
			);

			$this->add_responsive_control(
				'padding_title',
				[
					'label' 	 => esc_html__( 'Padding', 'anova' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova_give_detail .detail_body .title ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'margin_title',
				[
					'label' 	 => esc_html__( 'Margin', 'anova' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova_give_detail .detail_body .title ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		//END SECTION TAB STYLE TITLE


		$this->start_controls_section(
			'section_progress_style',
			[
				'label' => esc_html__( 'Progress', 'anova' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'color_progress_main',
				[
					'label' => esc_html__( 'Main Color', 'anova' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .give-progress .project-percent' => 'background-color : {{VALUE}} !important;',
					],
				]
			);

			$this->add_control(
				'color_progress',
				[
					'label' => esc_html__( 'Sub Color', 'anova' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .give-progress' => 'background-color : {{VALUE}} !important;',
					],
				]
			);

		$this->end_controls_section();

	}
	

	protected function render() {

		$settings = $this->get_settings();
	    
	    $type 			= $settings['type'];
		$layout_columns = $settings['layout_columns'];
		$category 		= $settings['category'];
		$number_items  	= $settings['number_items'];
		$order  		= $settings['order'];
		$orderby  		= $settings['orderby'];

		if ( $type == 'type4') {
			$layout_columns = '';
		};


		if ($settings['visibility'] != 'public') {
			$layout_show_post = array(
				array(
					'key' => 'ova_met_feature_give',
					'value' => 'on',
					'compare' => '=',
				)
			);
		} else {
			$layout_show_post = '';
		};

		$paged   = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;

		if ($category == 'all') {
		    $args_base = array(
				'post_type' 	 => 'give_forms',
				'posts_per_page' => $number_items,
				'orderby'		 => $orderby,
				'order'   		 => $order,
				'meta_query' 	 => $layout_show_post,
			);

		} else {
			$args_base = array(
				'post_type' 	 => 'give_forms',
				'posts_per_page' => $number_items,
				'orderby'		 => $orderby,
				'order'   		 => $order,
				'meta_query' 	 => $layout_show_post,
				'tax_query'      => array(
                    array(
                        'taxonomy' => 'give_forms_category',
                        'field'    => 'slug',
                        'terms'    => $category,
                    )
                ),
			);
		}

		$give_donation = new WP_Query( $args_base );

		if( in_array('give/give.php', apply_filters('active_plugins', get_option('active_plugins') ) ) ) {

		?>

			<div class="ova-item-give <?php echo esc_attr($layout_columns); ?>">

				 <?php if( $give_donation->have_posts() ) : while ( $give_donation->have_posts() ) : $give_donation->the_post();

					ob_start(); 

						if( $type === 'type1' ) {
				        		get_template_part( 'give/template-parts/item-give', null, $settings );

					        } elseif( $type === 'type2' ) {
					        	get_template_part( 'give/template-parts/item-give2', null, $settings );

					        } elseif( $type === 'type3' ) {
					        	get_template_part( 'give/template-parts/item-give3', null, $settings );

					        } elseif( $type === 'type4' ) {
					        	get_template_part( 'give/template-parts/item-give4', null, $settings );

					        } else {
					        	get_template_part( 'give/template-parts/item-give', null, $settings );
					    } 

					echo ob_get_clean(); ?>

				<?php endwhile; else: ?>

					<div class="search_not_found">
						<?php esc_html_e( 'Not Found Give Form', 'anova' ); ?>
					</div>

				<?php endif; wp_reset_postdata(); ?>

			</div>

		<?php } else {
			esc_html_e( 'Please active plugins Give Donations', 'anova' );;
		}
	}
}

$widgets_manager->register( new Anova_Elementor_Give_Donations() );