<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Anova_Elementor_Recent_News extends Widget_Base {

	
	public function get_name() {
		return 'anova_elementor_recent_news';
	}

	
	public function get_title() {
		return esc_html__( 'Recent News', 'anova' );
	}

	
	public function get_icon() {
		return 'eicon-post-list';
	}

	
	public function get_categories() {
		return [ 'anova' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$args = array(
			'orderby' 	=> 'name',
			'order' 	=> 'ASC'
		);

		$categories 	= get_categories($args);
		$cate_array 	= array();
		$arrayCateAll 	= array( 'all' => esc_html__( 'All categories', 'anova' ) );

		if ($categories) {
		 	foreach ( $categories as $cate ) {
				$cate_array[$cate->slug] = $cate->cat_name;
		  }
		} else {
		  	$cate_array[ esc_html__( 'No content Category found', 'anova' ) ] = 0;
		}

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'anova' ),
			]
		);	
			
			
			$this->add_control(
				'total_count',
				[
					'label' 	=> esc_html__( 'Post Total', 'anova' ),
					'type' 		=> \Elementor\Controls_Manager::NUMBER,
					'default' 	=> 5,
				]
			);

			$this->add_control(
			  	'category',
			  	[
				  	'label' 	=> esc_html__( 'Category', 'anova' ),
				  	'type' 		=> Controls_Manager::SELECT,
				  	'default' 	=> 'all',
				  	'options' 	=> array_merge($arrayCateAll,$cate_array),
			  	]
			);

			$this->add_control(
				'order',
				[
					'label' 	=> esc_html__('Order', 'anova'),
					'type' 		=> \Elementor\Controls_Manager::SELECT,
					'default' 	=> 'desc',
					'options' 	=> [
						'asc' => esc_html__('Ascending', 'anova'),
						'desc' => esc_html__('Descending', 'anova'),
					]
				]
			);

			$this->add_control(
				'order_by',
				[
					'label' 	=> esc_html__('Order By', 'anova'),
					'type' 		=> \Elementor\Controls_Manager::SELECT,
					'default' 	=> 'ID',
					'options' 	=> [
						'none' 		=> esc_html__('None', 'anova'),
						'ID' 		=> esc_html__('ID', 'anova'),
						'title' 	=> esc_html__('Title', 'anova'),
						'date' 		=> esc_html__('Date', 'anova'),
						'modified' 	=> esc_html__('Modified', 'anova'),
						'rand' 		=> esc_html__('Rand', 'anova'),
					]
				]
			);

		$this->end_controls_section();

		//SECTION TAB STYLE GENERAL
		$this->start_controls_section(
			'section_general_style',
			[
				'label' => esc_html__( 'General', 'anova' ),
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_responsive_control(
				'margin_item',
				[
					'label' 		=> esc_html__( 'Margin', 'anova' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', 'em', '%' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-recent-post .item .media' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		// END SECTION TAB STYLE General

		 
		//SECTION TAB STYLE TITLE
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'anova' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'title_typography',
					'selector' 	=> '{{WRAPPER}} .ova-recent-post .item .info .post-title',
				]
			);

			$this->add_control(
				'color_title',
				[
					'label' 	=> esc_html__( 'Color Title', 'anova' ),
					'type' 		=> \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-recent-post .item .info .post-title a' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'color_title_hover',
				[
					'label' 	=> esc_html__( 'Color Title Hover', 'anova' ),
					'type' 		=> \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-recent-post .item .info .post-title a:hover' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'margin_title',
				[
					'label' 	=> esc_html__( 'Margin', 'anova' ),
					'type' 		=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-recent-post .item .info .post-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);


		$this->end_controls_section();
		// END SECTION TAB STYLE TITLE
		
		//  DATE
		$this->start_controls_section(
			'section_date',
			[
				'label' => esc_html__( 'Date', 'anova' ),
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'date_typography',
					'selector' 	=> '{{WRAPPER}} .ova-recent-post .item .info .post-date',
					
				]
			);

			$this->add_control(
				'text_color_date',
				[
					'label' 	=> esc_html__( 'Text Color', 'anova' ),
					'type' 		=> \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-recent-post .item .info .post-date' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'icon__color',
				[
					'label' 	=> esc_html__( 'Icon Color', 'anova' ),
					'type' 		=> \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-recent-post .item .info .item-meta .icon' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'margin_date',
				[
					'label' 	=> esc_html__( 'Margin', 'anova' ),
					'type' 		=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-recent-post .item .info .post-date' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		// END SECTION TAB STYLE DATE
		
		//  Image
		$this->start_controls_section(
			'section_image',
			[
				'label' => esc_html__( 'Image', 'anova' ),
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
 			$this->add_responsive_control(
				'img_width',
				[
					'label' 		=> esc_html__( 'width', 'anova' ),
					'type' 			=> \Elementor\Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px' ],
					'range' => [
						'px' => [
							'min' 	=> 0,
							'max' 	=> 150,
							'step' 	=> 1,
						]
					],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-recent-post .item .media a img' => 'width: {{SIZE}}{{UNIT}}; min-width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'img_height',
				[
					'label' 		=> esc_html__( 'Height', 'anova' ),
					'type' 			=> \Elementor\Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px' ],
					'range' => [
						'px' => [
							'min' 	=> 0,
							'max' 	=> 100,
							'step' 	=> 1,
						]
					],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-recent-post .item .media a img' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);

 		$this->end_controls_section();
		// END SECTION TAB STYLE Image
		
	}

	// Render Template Here
	protected function render() {

		$settings 		= 	$this->get_settings();

		$category 		= 	$settings['category'];
		$total_count 	= 	$settings['total_count'];
		$order 			= 	$settings['order'];
		$order_by 		= 	$settings['order_by'];

		$args 	= [];
		$postid = get_the_ID(); 

		if ($category == 'all') {
		  $args=[
			  	'post_type' 		=> 'post',
			  	'post_status' 		=> 'publish',
			  	'posts_per_page' 	=> $total_count,
			  	'order' 			=> $order,
	  		    'orderby' 			=> $order_by,
	  		    'post__not_in' 		=> array( $postid ),
		  ];
		} else {
		  $args=[
			  	'post_type' 		=> 	'post', 
			  	'post_status' 		=> 'publish',
			  	'category_name'		=>	$category,
			  	'posts_per_page' 	=> 	$total_count,
			  	'order' 			=> 	$order,
	  		    'orderby' 			=>  $order_by,
	  		    'post__not_in' 		=>  array( $postid ),
			  	'fields'			=> 	'ids'
		  ];
		}

		$query = new WP_Query( $args );

		?>

		 <ul class="ova-recent-post">
			<?php
				if($query->have_posts()) : while($query->have_posts()) : $query->the_post();
			?>
				<li class="item">
						<div class="media">
				        	<?php 
				        		$thumbnail = wp_get_attachment_image_url(get_post_thumbnail_id() , 'thumbnail' );
				        		$url_thumb = $thumbnail ? $thumbnail : \Elementor\Utils::get_placeholder_image_src();

				        	?>
				        	<a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>">
				        		<img src="<?php echo esc_url( $url_thumb ) ?>" alt="<?php the_title(); ?>">
				        	</a>
				        </div>

				        <div class="info">

				        	<h4 class="post-title">
						        <a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>">
						          <?php the_title(); ?>
						        </a>
						    </h4>

				        	<div class="item-meta wp-date">
						    	<span class=" icon">
								   	<i class="icomoon icomoon-calendar"></i>
								</span>
								<div class=" post-date">
									<span class="date-j"><?php the_time('M j, Y' );?></span>
									
								</div>
							</div>
				            
				        </div>
				</li>
			<?php
				endwhile; endif; wp_reset_postdata();
			?>
		</ul>

		 	
		<?php
	}

	
}
$widgets_manager->register( new Anova_Elementor_Recent_News() );