<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Anova_Elementor_Team extends Widget_Base {

	
	public function get_name() {
		return 'anova_elementor_team';
	}

	
	public function get_title() {
		return esc_html__( 'Team', 'anova' );
	}

	
	public function get_icon() {
		return 'eicon-person';
	}

	
	public function get_categories() {
		return [ 'anova' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'anova' ),
			]
		);	

			$this->add_control(
				'version',
				[
					'label' 	=> esc_html__( 'Version', 'anova' ),
					'type' 		=> Controls_Manager::SELECT,
					'default' 	=> 'version_1',
					'options' 	=> [
						'version_1' => esc_html__( 'Version 1', 'anova' ),
						'version_2' => esc_html__( 'Version 2', 'anova' ),
						'version_3' => esc_html__( 'Version 3', 'anova' ),
					]
				]
			);
			
			$this->add_control(
				'ova_image',
				[
					'label' 	=> esc_html__( 'Choose Image', 'anova' ),
					'type' 		=> \Elementor\Controls_Manager::MEDIA,
					'default' 	=> [
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					],
				]
			);

			$this->add_control(
				 'name',
				[
					'label' 	=> esc_html__( 'Name', 'anova' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Kathryn Murphy', 'anova'),
				]
			);

			$this->add_control(
				 'job',
				[
					'label' 	=> esc_html__( 'Job', 'anova' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Volunteer', 'anova'),
					'condition' => [
						'version!' => 'version_2'
					],
				]
			);

			$this->add_control(
				 'job_v2',
				[
					'label' 	=> esc_html__( 'Job', 'anova' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__('City Council President', 'anova'),
					'condition' => [
						'version' => 'version_2'
					],
				]
			);

				$repeater = new \Elementor\Repeater();

				$repeater->add_control(
					'type',
					[
						'label' => esc_html__( 'Type', 'anova' ),
						'type' => Controls_Manager::SELECT,
						'default' => 'email',
						'options' => [
							'email' => esc_html__('Email', 'anova'),
							'phone' => esc_html__('Phone', 'anova'),
							'link' => esc_html__('Link', 'anova'),
							'text' => esc_html__('Text', 'anova'),
						],
					]
				);

				$repeater->add_control(
					'icon_email',
					[
						'label' => esc_html__( 'Class Icon', 'anova' ),
						'type' => \Elementor\Controls_Manager::ICONS,
						'default' 	=> [
							'value' 	=> 'icomoon icomoon-send-email',
							'library' 	=> 'icomoon',
						],
						'condition' => [
							'type' => 'email',
						]
					]
				);

				$repeater->add_control(
					'icon_phone',
					[
						'label' => esc_html__( 'Class Icon', 'anova' ),
						'type' => \Elementor\Controls_Manager::ICONS,
						'default' 	=> [
							'value' 	=> 'icomoon icomoon-phone-call',
							'library' 	=> 'icomoon',
						],
						'condition' => [
							'type' => 'phone',
						]
					]
				);

				$repeater->add_control(
					'icon_link',
					[
						'label' => esc_html__( 'Class Icon', 'anova' ),
						'type' => \Elementor\Controls_Manager::ICONS,
						'default' 	=> [
							'value' 	=> 'icomoon icomoon-pin',
							'library' 	=> 'icomoon',
						],
						'condition' => [
							'type' => 'link',
						]
					]
				);

				$repeater->add_control(
					'icon_text',
					[
						'label' => esc_html__( 'Class Icon', 'anova' ),
						'type' => \Elementor\Controls_Manager::ICONS,
						'default' 	=> [
							'value' 	=> 'icomoon icomoon-arroba',
							'library' 	=> 'icomoon',
						],
						'condition' => [
							'type' => 'text',
						]
					]
				);

				$repeater->add_control(
					'email_label',
					[
						'label'   => esc_html__( 'Email Label', 'anova' ),
						'type'    => \Elementor\Controls_Manager::TEXT,
						'description' => esc_html__( 'email@company.com', 'anova' ),
						'condition' => [
							'type' => 'email',
						]

					]
				);

				$repeater->add_control(
					'email_address',
					[
						'label'   => esc_html__( 'Email Adress', 'anova' ),
						'type'    => \Elementor\Controls_Manager::TEXT,
						'description' => esc_html__( 'email@company.com', 'anova' ),
						'condition' => [
							'type' => 'email',
						]

					]
				);


				$repeater->add_control(
					'phone_label',
					[
						'label'   => esc_html__( 'Phone Label', 'anova' ),
						'type'    => \Elementor\Controls_Manager::TEXT,
						'description' => esc_html__( '+012 (345) 678', 'anova' ),
						'condition' => [
							'type' => 'phone',
						]

					]
				);

				$repeater->add_control(
					'phone_address',
					[
						'label'   => esc_html__( 'Phone Adress', 'anova' ),
						'type'    => \Elementor\Controls_Manager::TEXT,
						'description' => esc_html__( '+012345678', 'anova' ),
						'condition' => [
							'type' => 'phone',
						]

					]
				);

				$repeater->add_control(
					'link_label',
					[
						'label'   => esc_html__( 'Link Label', 'anova' ),
						'type'    => \Elementor\Controls_Manager::TEXT,
						'description' => esc_html__( 'https://your-domain.com', 'anova' ),
						'condition' => [
							'type' => 'link',
						]

					]
				);

				$repeater->add_control(
					'link_address',
					[
						'label'   => esc_html__( 'Link Adress', 'anova' ),
						'type'    => \Elementor\Controls_Manager::URL,
						'description' => esc_html__( 'https://your-domain.com', 'anova' ),
						'condition' => [
							'type' => 'link',
						],
						'show_external' => false,
						'default' => [
							'url' => '#',
							'is_external' => false,
							'nofollow' => false,
						],

					]
				);

				$repeater->add_control(
					'text',
					[
						'label'   => esc_html__( 'Text', 'anova' ),
						'type'    => \Elementor\Controls_Manager::TEXT,
						'description' => esc_html__( 'Your text', 'anova' ),
						'condition' => [
							'type' => 'text',
						]

					]
				);

				$this->add_control(
					'items_info',
					[
						'label'       => esc_html__( 'Items Info', 'anova' ),
						'type'        => Controls_Manager::REPEATER,
						'fields'      => $repeater->get_controls(),
						'default' => [
							[
								'type' 			=> 'email',
								'email_label' 	=> esc_html__('director@citygov.com', 'anova'),
								'email_address' => esc_html__('director@citygov.com', 'anova'),
							],
							[
								'type' 			=> 'phone',
								'phone_label' 	=> esc_html__('(+91)8002359591', 'anova'),
								'phone_address' => esc_html__('+918002359591', 'anova'),
							],
							
						],
						'title_field' => '{{{ type }}}',
						'condition' =>[
							'version' => 'version_2',
						],
					]
				);


		//repeater social
		$repeater_social = new \Elementor\Repeater();

		$repeater_social->add_control(
			'list_title', [
				'label' 		=> esc_html__( 'Title', 'anova' ),
				'type' 			=> \Elementor\Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Item' , 'anova' ),
				'label_block' 	=> true,
			]
		);

		$repeater_social->add_control(
			'icon',
			[
				'label' 	=> esc_html__( 'Class Icon', 'anova' ),
				'type' 		=> \Elementor\Controls_Manager::ICONS,
				'default' 	=> [
					'value' 	=> 'fab fa-facebook',
					'library' 	=> 'icomoon',
				],
			]
		);

		$repeater_social->add_control(
			'link',
			[
				'label'   		=> esc_html__( 'Link Adress', 'anova' ),
				'type'    		=> \Elementor\Controls_Manager::URL,
				'description' 	=> esc_html__( 'https://your-domain.com', 'anova' ),
				'show_external' => false,
				'default' => [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],

			]
		);

		$this->add_control(
			'list_social',
			[
				'label' 	=> esc_html__( 'Social List', 'anova' ),
				'type' 		=> \Elementor\Controls_Manager::REPEATER,
				'fields' 	=> $repeater_social->get_controls(),
				'default' 	=> [
					[
						'list_title' => esc_html__( 'Facebook', 'anova' ),
						'link' 		=> [
							'url' => 'facebook.com'
						],
					],
					[
						'list_title' => esc_html__( 'Twitter', 'anova' ),
						'icon' => [
							'value' => 'icomoon icomoon-twitter',
						],
						'link' => [
							'url' => 'twitter.com'
						],
					],

					[
						'list_title' => esc_html__( 'Skype', 'anova' ),
						'icon' => [
							'value' => 'icomoon icomoon-skype',
						],
						'link' => [
							'url' => 'skype.com'
						],
					],
					
				],
				'title_field' => '{{{ list_title }}}',
				'condition' =>[
					'version' => 'version_3',
				],
			]
		);

		$this->end_controls_section();

		/**
		 * GENERAL Style Tab
		 */
		$this->start_controls_section(
			'section_general',
			[
				'label' => esc_html__( 'General', 'anova' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' 		=> 'general_box_shadow',
					'label' 	=> esc_html__( 'Box Shadow', 'anova' ),
					'selector' 	=> '{{WRAPPER}}  .ova-team .team-version_3,.ova-team .team-version_2',
					'condition' => [
						'version!' => 'version_1',
					],
				]
			);

			$this->add_responsive_control(
				'general_padding',
				[
					'label' 	=> esc_html__( 'Padding Info', 'anova' ),
					'type' 		=> Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-team .team-version_1 .info' 		=> 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						'{{WRAPPER}} .ova-team .team-version_2 .content' 	=> 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						'{{WRAPPER}} .ova-team .team-version_3 .info' 		=> 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);		

			$this->add_control(
				'border_contact_info',
				[
					'label' 	=> esc_html__( 'Border Contact Info', 'anova' ),
					'type' 		=> \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'version' => 'version_2',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' 		=> 'border_name_job',
					'label' 	=> esc_html__( 'Border Name Job', 'anova' ),
					'selector' 	=> '{{WRAPPER}} .ova-team .team-version_2 .contact-info ',
					'condition' => [
						'version' => 'version_2',
					],
				]
			);

		$this->end_controls_section();
		// end style tab ganeral //
		
		/** 
		 * IMAGE Style Tab
		*/
		$this->start_controls_section(
			'section_image_style',
			[
				'label' => esc_html__( 'Image', 'anova' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_responsive_control(
				'image_height',
				[
					'label' => esc_html__( 'Height', 'anova' ),
					'type' 	=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 100,
							'max' => 500,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-team .team-version_1 .team-avatar img' => 'height: {{SIZE}}{{UNIT}}',
						'{{WRAPPER}} .ova-team .team-version_2 .team-avatar img' => 'height: {{SIZE}}{{UNIT}}',
						'{{WRAPPER}} .ova-team .team-version_3 .team-avatar img' => 'height: {{SIZE}}{{UNIT}}',
					],
				]
			);

			$this->add_responsive_control(
				'image_border_radius',
				[
					'label' 		=> esc_html__( 'Border Radius', 'anova' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', 'em', '%' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-team .team-version_1' 	=> 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						'{{WRAPPER}} .ova-team .team-version_2' 	=> 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						'{{WRAPPER}} .ova-team .team-version_3' 	=> 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						'{{WRAPPER}} .ova-team .team-avatar img' 	=> 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'image_margin',
				[
					'label' 	=> esc_html__( 'Margin', 'anova' ),
					'type' 		=> Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-team .team-avatar' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);	

		$this->end_controls_section();
		// end style tab Image //
		
		/**
		 * NAME Style Tab
		 */
		$this->start_controls_section(
			'section_name_style',
			[
				'label' => esc_html__( 'Name', 'anova' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);
		
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'name_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team .info .name',
				]
			);

			$this->add_control(
				'name_color',
				[
					'label' 	=> esc_html__( 'Color', 'anova' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-team .info .name' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'name_padding',
				[
					'label' 	=> esc_html__( 'Padding', 'anova' ),
					'type' 		=> Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-team .info .name' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);			

			$this->add_responsive_control(
				'name_margin',
				[
					'label' 	=> esc_html__( 'Margin', 'anova' ),
					'type' 		=> Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-team .info .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' 		=> 'border_name',
					'label' 	=> esc_html__( 'Border Name', 'anova' ),
					'selector' 	=> '{{WRAPPER}} .ova-team .team-version_3 .info .name-social ',
					'condition' => [
						'version' => 'version_3'
					],
				]
			);

		$this->end_controls_section();
		// end style tab Title //
		
		/**
		 * JOB Style Tab
		 */
		$this->start_controls_section(
			'section_job_style',
			[
				'label' => esc_html__( 'Job', 'anova' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);
		
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'job_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team .info .job',
				]
			);

			$this->add_control(
				'job_color',
				[
					'label' 	=> esc_html__( 'Color', 'anova' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-team .info .job' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'job_padding',
				[
					'label' 	=> esc_html__( 'Padding', 'anova' ),
					'type' 		=> Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-team .info .job' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);			

			$this->add_responsive_control(
				'job_margin',
				[
					'label' 	=> esc_html__( 'Margin', 'anova' ),
					'type' 		=> Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-team .info .job' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		// end style tab Job //
		
		/** 
		 * Social Style Tab
		*/
		$this->start_controls_section(
			'section_icon_social_style',
			[
				'label' 	=> esc_html__( 'Social', 'anova' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
				'condition' => [
					'version' =>'version_3'
				]
			]
		);

			$this->add_control(
				'icon_fontsize',
				[
					'label' 	=> esc_html__( 'Font Size', 'anova' ),
					'type' 		=> Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' 	=> [
						'px' => [
							'min' 	=> 10,
							'max' 	=> 60,
							'step' 	=> 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .ova-team .team-version_3 .info .name-social .contact-info .item-social' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'icon_color',
				[
					'label' 	=> esc_html__( 'Color', 'anova' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-team .team-version_3 .info .name-social .contact-info .item-social' => 'color : {{VALUE}};',
					],
				]
			);

		$this->end_controls_section();
		// end style tab Social //
		
		/** 
		 * Contact Info Style Tab
		*/
		$this->start_controls_section(
			'section_contact_info_style',
			[
				'label' 	=> esc_html__( 'Contact Info', 'anova' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
				'condition' => [
					'version' =>'version_2'
				]
			]
		);

			$this->add_control(
				'icon_contact_info_heading',
				[
					'label' 	=> esc_html__( 'Icon Contact Info', 'anova' ),
					'type' 		=> \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
					
				]
			);

			$this->add_control(
				'icon_contact_info_fontsize',
				[
					'label' 	=> esc_html__( 'Font Size', 'anova' ),
					'type' 		=> Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' 	=> [
						'px' => [
							'min' 	=> 10,
							'max' 	=> 60,
							'step' 	=> 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .ova-team .team-version_2 .contact-info .item .icon' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'icon_contact_info_color',
				[
					'label' 	=> esc_html__( 'Color', 'anova' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-team .team-version_2 .contact-info .item .icon' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'icon_contact_info_margin',
				[
					'label' 	=> esc_html__( 'Margin', 'anova' ),
					'type' 		=> Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-team .team-version_2 .contact-info .item .icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);		

			$this->add_responsive_control(
				'icon_contact_info_padding',
				[
					'label' 	=> esc_html__( 'Padding', 'anova' ),
					'type' 		=> Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-team .team-version_2 .contact-info .item .icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);		


			$this->add_control(
				'content_contact_info_heading',
				[
					'label' 	=> esc_html__( 'Content Contact Info', 'anova' ),
					'type' 		=> \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
					
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_contact_info_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team .team-version_2 .contact-info .item a',
				]
			);

			$this->add_control(
				'content_contact_info_color',
				[
					'label' 	=> esc_html__( 'Color', 'anova' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-team .team-version_2 .contact-info .item a' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'content_contact_info_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'anova' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-team .team-version_2 .contact-info .item a:hover' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'content_contact_info_padding',
				[
					'label' 	=> esc_html__( 'Padding', 'anova' ),
					'type' 		=> Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-team .team-version_2 .contact-info .item a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);	

			$this->add_responsive_control(
				'content_contact_info_margin',
				[
					'label' 	=> esc_html__( 'Margin', 'anova' ),
					'type' 		=> Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-team .team-version_2 .contact-info .item a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);		




		$this->end_controls_section();
		// end style tab Contact Info //

	}

	// Render Template Here
	protected function render() {

		$settings 		= 	$this->get_settings();
		$version 		= 	$settings['version'];

		$image 			= 	$settings['ova_image'] ? $settings['ova_image'] : \Elementor\Utils::get_placeholder_image_src();
		$img_alt 		= 	isset( $settings['image']['alt'] ) ? $settings['image']['alt'] : '';
		$name 			=  	$settings['name'];
		$job 			=  	$settings['job'];

		//version 2
		$items_info 	= 	$settings['items_info'];		
		if($version === 'version_2'){
			$job 	= 	$settings['job_v2'];
		}
		//version 3
		$items_social 	= 	$settings['list_social'];
		 ?>

		<div class="ova-team">
			<div class="team-<?php echo esc_attr( $version ); ?>">
				<div class="team-avatar">
					<img src="<?php echo esc_url( $image['url'] ); ?>" alt="<?php echo esc_attr( $img_alt ); ?>">	
				</div>
			<?php if( $version==='version_2' ): ?>
				<div class="content">
			<?php endif; ?>
				<div class="info">
					<?php if( $version==='version_3' ): ?>
						<div class="name-social">
					<?php endif; ?>
					
					<?php if( $name ) { ?>
						<h3 class="name"> <?php echo esc_html( $name ); ?> </h3>
					<?php } ?>

					<?php if( $version==='version_3' ): ?>
							<div class="contact-info">
								<?php foreach( $items_social as $item ): 
									$icon 	= $item['icon'];
									$link 	= $item['link']['url'];
									$target = $item['link']['is_external'] ? ' target="_blank"' : '';
								?>
								<a href="<?php echo esc_url( $link ); ?>"<?php printf( $target ); ?> class="item-social">
									<?php \Elementor\Icons_Manager::render_icon( $icon, [ 'aria-hidden' => 'true' ] ); ?>
								</a>

								<?php endforeach; ?>
							</div>
						</div>
					<?php endif; ?>

					<?php if( $job ) { ?>
						<p class="job"> <?php echo esc_html( $job ); ?> </p>
					<?php } ?>

				</div>

				<?php if( $version==='version_2'): ?>

						<ul class="contact-info">
							<?php foreach( $items_info as $item ):

								$type 	= $item['type'];
								
								?>

									<li class="item">

										<?php switch ( $type ) {

											case 'email':

												$email_address 	= $item['email_address'];
												$email_label 	= $item['email_label'];
												$icon 			= $item['icon_email'];

												if( $icon ){ ?>
													<div class="icon">
														<?php 
													        \Elementor\Icons_Manager::render_icon( $icon, [ 'aria-hidden' => 'true' ] );
													    ?>
													</div> 
												<?php }

												if( $email_address && $email_label ){
												?>
													<a href="mailto:<?php echo esc_attr( $email_address ); ?> ">
														<?php echo esc_html( $email_label ); ?>
													</a>
												<?php
												}

												break;

											case 'phone':

												$phone_address 	= $item['phone_address'];
												$phone_label 	= $item['phone_label'];
												$icon 			= $item['icon_phone'];

												if( $icon ){ ?>
													<div class="icon">
														<?php 
													        \Elementor\Icons_Manager::render_icon( $icon, [ 'aria-hidden' => 'true' ] );
													    ?>
													</div> 
												<?php }
												 if( $phone_address && $phone_label ){
												?>
													<a href="tel:<?php echo esc_attr( $phone_address ) ?> ">
														<?php echo esc_html( $phone_label ); ?>
													</a>
												<?php
												}

												break;

											case 'link':

												$this->add_render_attribute( 'title' );

												$link_address 	= $item['link_address']['url'];
												$link_label 	= $item['link_label'];
												$title 			= $item['link_label'] ? $item['link_label'] : '';
												$icon 			= $item['icon_link'];

												if( $icon ){ ?>
													<div class="icon">
														<?php 
													        \Elementor\Icons_Manager::render_icon( $icon, [ 'aria-hidden' => 'true' ] );
													    ?>
													</div> 
												<?php }

												 if ( ! empty( $item['link_address']['url'] ) ) {

													$this->add_link_attributes( 'url', $item['link_address'] );
													echo sprintf( '<a %1$s>%2$s</a>', $this->get_render_attribute_string( 'url' ), $title );

												} else {
													echo esc_html( $title );
												}
												
												break;

											case 'text':
												$text = $item['text'];
												$icon = $item['icon_text'];

												if( $icon ){ ?>
													<div class="icon">
														<?php 
													        \Elementor\Icons_Manager::render_icon( $icon, [ 'aria-hidden' => 'true' ] );
													    ?>
													</div> 
												<?php }
													echo esc_html( $text ); ?>
												<?php

												break;
											default:
												break;
										} ?>
									</li>
								
							<?php endforeach; ?>
						</ul>
				<?php endif; ?>
				<?php if( $version === 'version_2'): ?>
					</div>
				<?php endif; ?>
				
			</div>
		</div>
		 	
		<?php
	}

	
}
$widgets_manager->register( new Anova_Elementor_Team() );