<?php

class Anova_Elementor {
	
	function __construct() {
            
		// Register Header Footer Category in Pane
	    add_action( 'elementor/elements/categories_registered', array( $this, 'anova_add_category' ) );

	    add_action( 'elementor/frontend/after_register_scripts', array( $this, 'anova_enqueue_scripts' ) );
		
		add_action( 'elementor/widgets/register', array( $this, 'anova_include_widgets' ) );
		
		add_filter( 'elementor/controls/animations/additional_animations', array( $this, 'anova_add_animations'), 10 , 0 );

		add_action( 'wp_print_footer_scripts', array( $this, 'anova_enqueue_footer_scripts' ) );

		// load icons
		add_filter( 'elementor/icons_manager/additional_tabs', array( $this, 'anova_icons_filters_new' ), 9999999, 1 );

		// customize social icon
		add_action( 'elementor/element/social-icons/section_social_hover/after_section_end', array( $this, 'anova_social_icons_custom' ), 10, 2 );

		// customize icon box
		add_action( 'elementor/element/icon-box/section_style_content/after_section_end', array( $this, 'anova_icons_box_customize' ), 10, 2 );

		//Add Arccordion customize
		add_action( 'elementor/element/accordion/section_toggle_style_content/after_section_end', array( $this, 'anova_accordion_customize' ), 10, 2 );

		//Add Divider customize
		add_action( 'elementor/element/divider/section_icon_style/after_section_end', array( $this, 'anova_divider_customize' ), 10, 2 );

	}

	
	function anova_add_category(  ) {

	    \Elementor\Plugin::instance()->elements_manager->add_category(
	        'hf',
	        [
	            'title' => __( 'Header Footer', 'anova' ),
	            'icon' => 'fa fa-plug',
	        ]
	    );

	    \Elementor\Plugin::instance()->elements_manager->add_category(
	        'anova',
	        [
	            'title' => __( 'Anova', 'anova' ),
	            'icon' => 'fa fa-plug',
	        ]
	    );

	}

	function anova_enqueue_scripts(){
        
        $files = glob(get_theme_file_path('/assets/js/elementor/*.js'));
        
        foreach ($files as $file) {
            $file_name = wp_basename($file);
            $handle    = str_replace(".js", '', $file_name);
            $src       = get_theme_file_uri('/assets/js/elementor/' . $file_name);
            if (file_exists($file)) {
                wp_register_script( 'anova-elementor-' . $handle, $src, ['jquery'], false, true );
            }
        }


	}

	function anova_include_widgets( $widgets_manager ) {
        $files = glob(get_theme_file_path('elementor/widgets/*.php'));
        foreach ($files as $file) {
            $file = get_theme_file_path('elementor/widgets/' . wp_basename($file));
            if (file_exists($file)) {
                require_once $file;
            }
        }
    }

    function anova_add_animations(){
    	$animations = array(
            'Anova' => array(
                'ova-move-up' 		=> esc_html__('Move Up', 'anova'),
                'ova-move-down' 	=> esc_html__( 'Move Down', 'anova' ),
                'ova-move-left'     => esc_html__('Move Left', 'anova'),
                'ova-move-right'    => esc_html__('Move Right', 'anova'),
                'ova-scale-up'      => esc_html__('Scale Up', 'anova'),
                'ova-flip'          => esc_html__('Flip', 'anova'),
                'ova-helix'         => esc_html__('Helix', 'anova'),
                'ova-popup'			=> esc_html__( 'PopUp','anova' )
            ),
        );

        return $animations;
    }

   

	function anova_enqueue_footer_scripts(){
		 // Font Icon
	    wp_enqueue_style('ovaicon', ANOVA_URI.'/assets/libs/ovaicon/font/ovaicon.css', array(), null);

	     // Icomoon
	    wp_enqueue_style('icomoon', ANOVA_URI.'/assets/libs/icomoon/style.css', array(), null);
	}
	
	

	public function anova_icons_filters_new( $tabs = array() ) {

		$newicons = [];
		$font_data['json_url'] = ANOVA_URI.'/assets/libs/ovaicon/ovaicon.json';
		$font_data['name'] = 'ovaicon';

		$newicons[ $font_data['name'] ] = [
			'name'          => $font_data['name'],
			'label'         => esc_html__( 'Default', 'anova' ),
			'url'           => '',
			'enqueue'       => '',
			'prefix'        => 'ovaicon-',
			'displayPrefix' => '',
			'ver'           => '1.0',
			'fetchJson'     => $font_data['json_url'],
			
		];

		// Icomoon
		$font_icomoon_data['json_url'] = ANOVA_URI.'/assets/libs/icomoon/icomoon.json';
		$font_icomoon_data['name'] = 'icomoon';

		$newicons[ $font_icomoon_data['name'] ] = [
			'name'          => $font_icomoon_data['name'],
			'label'         => esc_html__( 'Icomoon', 'anova' ),
			'url'           => '',
			'enqueue'       => '',
			'prefix'        => 'icomoon-',
			'displayPrefix' => '',
			'ver'           => '1.0',
			'fetchJson'     => $font_icomoon_data['json_url']
		];

		return array_merge( $tabs, $newicons );

	}

	function anova_social_icons_custom ( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_social_icons',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Social Icon', 'anova' ),
			]
		);

			$element->add_responsive_control(
	            'ova_social_icons_display',
	            [
	                'label' 	=> esc_html__( 'Display', 'anova' ),
	                'type' 		=> \Elementor\Controls_Manager::CHOOSE,
	                'options' 	=> [
	                    'inline-block' => [
	                        'title' => esc_html__( 'Block', 'anova' ),
	                        'icon' 	=> 'eicon-h-align-left',
	                    ],
	                    'inline-flex' => [
	                        'title' => esc_html__( 'Flex', 'anova' ),
	                        'icon' 	=> 'eicon-h-align-center',
	                    ],
	                ],
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-icon.elementor-social-icon' => 'display: {{VALUE}}',
	                ],
	            ]
	        );

		$element->end_controls_section();
	}
    
    function anova_icons_box_customize ( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_icons_box_customize',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Icon Box', 'anova' ),
			]
		);	

			$element->add_control(
				'ova_icon_box_title',
				[
					'label' => esc_html__( 'Title', 'anova' ),
					'type' => Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$element->add_responsive_control(
				'icon_box_title_margin',
				[
					'label' 		=> esc_html__( 'Margin', 'anova' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
					'{{WRAPPER}}  .elementor-icon-box-content .elementor-icon-box-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$element->add_control(
				'ova_icon_box_hover',
				[
					'label' => esc_html__( 'Hover', 'anova' ),
					'type' => Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$element->add_control(
	            'icon_box_hover_title',
	            [
	                'label' 	=> esc_html__( 'Color Title Hover', 'anova' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-icon-box-wrapper:hover .elementor-icon-box-content .elementor-icon-box-title' => 'color: {{VALUE}} ;',
	                ],
	            ]
	        );

	        $element->add_control(
	            'icon_box_hover_desc',
	            [
	                'label' 	=> esc_html__( 'Color Description Hover', 'anova' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-icon-box-wrapper:hover .elementor-icon-box-content .elementor-icon-box-description' => 'color: {{VALUE}} ;',
	                ],
	            ]
	        );

	        $element->add_control(
	            'icon_box_hover_icon',
	            [
	                'label' 	=> esc_html__( 'Color Description Hover', 'anova' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-icon-box-wrapper:hover .elementor-icon-box-icon .elementor-icon' => 'color: {{VALUE}} ;',
	                ],
	            ]
	        );

		$element->end_controls_section();
	}

	// anova_accordion_customize
	function anova_accordion_customize ( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_accordion',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Accordion', 'anova' ),
			]
		);
			// General
			$element->add_control(
				'ova_accordion_heading_title_item',
				[
					'label' => esc_html__( 'title Item', 'anova' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$element->add_control(
	            'ova_accordion_background_title_Active',
	            [
	                'label' 	=> esc_html__( 'Background Title Active', 'anova' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-accordion-item .elementor-tab-title.elementor-active' => 'background-color: {{VALUE}} ;',
	                ],
	            ]
	        );

	        $element->add_responsive_control(
				'ova_accordion_margin_item',
				[
					'label' 		=> esc_html__( 'Margin', 'anova' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
					'{{WRAPPER}}  .elementor-accordion-item:not(:last-child)' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$element->end_controls_section();
	}

	// anova_accordion_customize
	function anova_divider_customize ( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_anova_divider_customize',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Divider', 'anova' ),
			]
		);

			// General
			$element->add_control(
				'ova_divider_heading',
				[
					'label' => esc_html__( 'Display Vertical', 'anova' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);
			// 
			$element->add_responsive_control(
	            'ova_divider_display',
	            [
	                'label' 	=> esc_html__( 'Vertical', 'anova' ),
	                'type' 		=> \Elementor\Controls_Manager::CHOOSE,
	                'options' 	=> [
	                    'start' => [
	                        'title' => esc_html__( 'Top', 'anova' ),
	                        'icon' 	=> 'eicon-v-align-top',
	                    ],
	                    'baseline' => [
	                        'title' => esc_html__( 'Bottom', 'anova' ),
	                        'icon' 	=> 'eicon-v-align-bottom ',
	                    ],
	                ],
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-divider .elementor-divider-separator' => 'align-items: {{VALUE}}',
	                ],
	            ]
	        );


		$element->end_controls_section();
	}

}

return new Anova_Elementor();





